import 'dart:developer';

import 'package:flutter_riverpod/flutter_riverpod.dart';

class ProvidersLogger extends ProviderObserver {
  ProvidersLogger({this.logger = true});

  final bool logger;
  @override
  void didAddProvider(
    ProviderBase<Object?> provider,
    Object? value,
    ProviderContainer container,
  ) {
    if (provider.name != null && logger) {
      log('didAddProvider($value)', name: '${provider.name}');
    }
  }

  @override
  void didUpdateProvider(
    ProviderBase<Object?> provider,
    Object? previousValue,
    Object? newValue,
    ProviderContainer container,
  ) {
    if (provider.name != null && logger) {
      log('didUpdateProvider($newValue)', name: '${provider.name}');
    }
  }

  @override
  void providerDidFail(
    ProviderBase<Object?> provider,
    Object error,
    StackTrace stackTrace,
    ProviderContainer container,
  ) {
    if (provider.name != null && logger) {
      log('providerDidFail($error)', name: '${provider.name}');
    }
  }

  @override
  void didDisposeProvider(ProviderBase provider, ProviderContainer container) {
    if (provider.name != null && logger) {
      log('didDisposeProvider', name: '${provider.name}');
    }
  }
}
